import os
import subprocess
import customtkinter
from PIL import Image
from tkinter import messagebox

# List of materials for Mat1 and Mat2
mat1_options = ["Al2O3", "CsCl", "hBN", "KBr", "KCl", "MgO", "NaCl"]
mat2_options = ["Au", "fccCo", "bccFe", "fccFe", "hcpFe", "MgO", "Mo", "Ni", "Pt", "Re", "W"]

def start_script():
    mat1 = mat1_var.get()
    mat2 = mat2_var.get()
    
    if not mat1 or not mat2:
        messagebox.showerror("Error", "Please select both materials.")
        return
    
    filename = f"MBase_{mat1}+{mat2}.py"
    
    if os.path.exists(filename):
        try:
            # Run the script in a separate subprocess
            subprocess.Popen(["python", filename], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            #messagebox.showinfo("Script Started", f"Script '{filename}' has started.")
        except Exception as e:
            messagebox.showerror("Error", f"Failed to start script '{filename}': {str(e)}")
    else:
        messagebox.showerror("Error", f"Script '{filename}' not found.")

def callback(url):
    import webbrowser
    webbrowser.open_new(url)

# Create the main window
root = customtkinter.CTk()  
root.geometry('770x360')     
root.resizable(width=False, height=False)
root.title("EosCross by R. Farla - powered by Burnman")  

# Create the main frames for layout
left_frame = customtkinter.CTkFrame(root)
middle_frame = customtkinter.CTkFrame(root)
right_frame = customtkinter.CTkFrame(root)

left_frame.pack(side='left', padx=10, pady=5, fill='y')
middle_frame.pack(side='left', padx=10, pady=5, fill='y')
right_frame.pack(side='right', padx=10, pady=5, fill='y')

# Text, left
instruct = customtkinter.CTkLabel(left_frame, text="Usage instructions", font=('Arial', 14, 'bold'))
instruct.pack(padx=5, pady=5)
instruct.configure(width=200)

# Left Frame with Textbox for paragraph
paragraph_text = """Welcome to EosCross! \n\nChoose two materials from the dropdown lists on the right, and click on the 'open' button. The associated script will start in a new instance of python, please be patient. You can start multiple scripts for different pairs of materials.
\nThis app has the following features:\n\n\u2022 Single P and Joint PT estimation using\n  many known published EoS.\n\u2022 Data export to txt file.\n\u2022 Data import (e.g. from GSAS) for batch\n  calculations of pressures.\n\u2022 Uncertainty propagation of temperature\n  and unit cell parameter/volume to\n  pressure (PVT correlation matrix). """

# Textbox for the paragraph
paragraph_box = customtkinter.CTkTextbox(left_frame, width=250, height=340, wrap='word', font=('Arial', 12), fg_color='#2B2B2B')
paragraph_box.pack(padx=5, pady=5)

# Insert the paragraph text and configure alignment
paragraph_box.insert("1.0", paragraph_text)
paragraph_box.configure(state="disabled")  # Disable editing

# Title center
instruct = customtkinter.CTkLabel(middle_frame, text="Launch script", font=('Arial', 14, 'bold'))
instruct.pack(padx=20, pady=5)

# Material 1 Dropdown, middle
customtkinter.CTkLabel(middle_frame, text="Select Material 1:").pack(pady=5)
mat1_var = customtkinter.StringVar(value="")
mat1_dropdown = customtkinter.CTkOptionMenu(middle_frame, variable=mat1_var, values=mat1_options)
mat1_dropdown.pack(padx=20, pady=5)

# Material 2 Dropdown, middle
customtkinter.CTkLabel(middle_frame, text="Select Material 2:").pack(pady=5)
mat2_var = customtkinter.StringVar(value="")
mat2_dropdown = customtkinter.CTkOptionMenu(middle_frame, variable=mat2_var, values=mat2_options)
mat2_dropdown.pack(padx=20, pady=5)

# Start Button, middle
start_button = customtkinter.CTkButton(middle_frame, text="Open", command=start_script)
start_button.pack(padx=20, pady=20)

# Picture Frame, right
label = customtkinter.CTkLabel(right_frame, text="Loading scripts takes a moment!", font=('Arial', 14, 'bold'))
label.pack(side='top', fill='both', padx=20, pady=5)

link = customtkinter.CTkLabel(right_frame, text="R. Farla v1.3 - Gitlab DESY", font=('Arial', 12, 'bold'), cursor="hand2")
link.pack(side='bottom', fill='both', padx=20, pady=5)
link.bind("<Button-1>", lambda e: callback('https://gitlab.desy.de/robert.farla/eoscross/'))

# Load and display the image
image_path = 'EosCross_icon.png'  # Replace with your actual image path
image1 = Image.open(image_path)
test = customtkinter.CTkImage(image1, size=(250, 250))
label1 = customtkinter.CTkLabel(right_frame, image=test, text="")
label1.image = test
label1.pack(side='right', fill='both', padx=20, pady=15)

# Run the application
root.mainloop()
