# This file is part of EosCross, a utility to jointly estimate pressure and temperature, written by R. Farla.

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_tkagg import (
    FigureCanvasTkAgg, NavigationToolbar2Tk)
from functools import partial
import tkinter as tk
from tkinter import filedialog
from intersect import intersection
from tkinter import messagebox
import customtkinter
import os
import subprocess
from PIL import Image 

# Import phase files
from single import Alumina1_Shi2022
from single import Alumina1_Dewaele2013
from single import Alumina1_Dubrovinsky1998
#from single import 
#from single import 

from single import Fe_bcc2_Dorogokupets2017
from single import Fe_bcc2_Zhang1999
#from single import 
#from single import 
#from single import 

"""
User input
"""

EoStitle = 'Al2O3 + bcc-Fe'
EoS1_1 = Alumina1_Shi2022
EoS1_2 = Alumina1_Dewaele2013
EoS1_3 = Alumina1_Dubrovinsky1998
#oS1_4 = 
#EoS1_5 = 

EoS2_1 = Fe_bcc2_Dorogokupets2017
EoS2_2 = Fe_bcc2_Zhang1999
#EoS2_3 = 
#EoS2_4 = 
#EoS2_5 = 

EoS1nm = "Al2O3 "
EoS1Entry_1 = "Shi2022*"
EoS1Entry_2 = "Dewaele2013"
EoS1Entry_3 = "Dubrovinsky1998"
#EoS1Entry_4 = ""
#EoS1Entry_5 = ""

EoS2nm = "bcc-Fe ( < 1000 K ) "
EoS2Entry_1 = "Dorogokupets2017*"
EoS2Entry_2 = "Zhang1999"
#EoS2Entry_3 = ""
#EoS2Entry_4 = ""
#EoS2Entry_5 = ""

EoS1a = 255.1
EoS1a0 = 255.1
EoS2a = 2.8665
EoS2a0 = 2.8665
EoS1unit = "V" #or V
EoS2unit = "a" #or V
EoS1unit0 = "V0" #or V0
EoS2unit0 = "a0" #or V0

EoS1uniterr = "V esd" #or V esd
EoS2uniterr = "a esd" #or V esd
EoS1aerr = 0.0001
EoS2aerr = 0.0001 #Metals are usually more sensitive to pressure changes (smaller peak shift/changes in volume)
Pbar = 0.0
Pow = 0.0

"""
Functions, do not modify
"""

def open_file():
    file_path = filedialog.askopenfilename(title="Select a file", filetypes=[("Text files", "*.txt"), ("All files", "*.*")])
    with open('path.txt', 'w') as file:
        file.write(file_path)

def close(): # close program
    if messagebox.askyesno(title='Quit?', message='Do you want to quit?'):
        root.quit()

def zoom_factory(ax,base_scale = 2.):
    def zoom_fun(event):
        # get the current x and y limits
        cur_xlim = ax.get_xlim()
        cur_ylim = ax.get_ylim()
        cur_xrange = (cur_xlim[1] - cur_xlim[0])*.5
        cur_yrange = (cur_ylim[1] - cur_ylim[0])*.5
        xdata = event.xdata # get event x location
        ydata = event.ydata # get event y location
        if event.button == 'up':
            # deal with zoom in
            scale_factor = 1/base_scale
        elif event.button == 'down':
            # deal with zoom out
            scale_factor = base_scale
        else:
            # deal with something that should never happen
            scale_factor = 1
            print(event.button)
        # set new limits
        ax.set_xlim([xdata - cur_xrange*scale_factor,
                     xdata + cur_xrange*scale_factor])
        ax.set_ylim([ydata - cur_yrange*scale_factor,
                     ydata + cur_yrange*scale_factor])
        plt.draw() # force re-draw

    fig = ax.get_figure() # get the figure of interest
    # attach the call back
    fig.canvas.mpl_connect('scroll_event',zoom_fun)

    #return the function
    return zoom_fun

def polyfiteqn(label_T, label_P, label_Tmin, label_Pmin, label_Tmax, label_Pmax, label_deltaT, label_deltaP, unc1, unc2, label_noerror):
    plt.clf()
    
    global resetfields
    
    P_1 = 'P_1.txt'
    dataP1 = np.loadtxt(P_1, delimiter=',', dtype=float)
    T_1 = 'T_1.txt'
    dataT1 = np.loadtxt(T_1, delimiter=',', dtype=float)
    
    P_2 = 'P_2.txt'
    dataP2 = np.loadtxt(P_2, delimiter=',', dtype=float)
    T_2 = 'T_2.txt'
    dataT2 = np.loadtxt(T_2, delimiter=',', dtype=float)
   
    xi, yi = intersection(dataT1, dataP1 / 1.0e9, dataT2, dataP2 / 1.0e9)
    
    if xi.shape[0] == 1:
        label_T.configure(text=" %.2f" % xi[0])
        label_P.configure(text=" %.3f" % yi[0])
        noerror = "Isochors intersect"
        label_noerror.configure(text=noerror)
        resetfields = 0
    else: 
        label_noerror.configure(text="Isochors do not intersect!  Ignore P-T estimation!")
        label_T.configure(text="")
        label_P.configure(text="")
        resetfields = 1
    
    dataP1plus = dataP1 + Perr1 * 1.0e9
    dataP1min = dataP1 - Perr1 * 1.0e9
    dataP2plus = dataP2 + Perr2 * 1.0e9
    dataP2min = dataP2 - Perr2 * 1.0e9
    
    dataT1plus = dataT1 + Terr1
    dataT1min = dataT1 - Terr1
    dataT2plus = dataT2 + Terr2
    dataT2min = dataT2 - Terr2
    
      #If P1 is 'shallower' than P2
    ximin, yimin = intersection(dataT1, dataP1min / 1.0e9, dataT1, dataP2plus / 1.0e9)
    ximax, yimax = intersection(dataT1, dataP1plus / 1.0e9, dataT1, dataP2min / 1.0e9)
      #If P1 is 'steeper' than P2
    #ximin, yimin = intersection(dataT1, dataP1plus / 1.0e9, dataT1, dataP2min / 1.0e9)
    #ximax, yimax = intersection(dataT1, dataP1min / 1.0e9, dataT1, dataP2plus / 1.0e9)
    
    DeltaT = abs(ximax - ximin) 
    DeltaP = abs(yimax - yimin) 
          
    if ximin.shape[0] == 1:
        label_Tmin.configure(text=" %.2f" % ximin[0])
        label_Pmin.configure(text=" %.3f" % yimin[0])
        noerror = "Isochors intersect"
        label_noerror.configure(text=noerror)
    else: 
        label_Tmin.configure(text="")
        label_Pmin.configure(text="")
    
    if ximax.shape[0] == 1:
        label_Tmax.configure(text=" %.2f" % ximax[0])
        label_Pmax.configure(text=" %.3f" % yimax[0])
        noerror = "Isochors intersect"
        label_noerror.configure(text=noerror)
    else: 
        label_Tmax.configure(text="")
        label_Pmax.configure(text="")
    
    if ximin.shape[0] == 1:
        label_deltaT.configure(text=" %.2f" % DeltaT[0])
        label_deltaP.configure(text=" %.3f" % DeltaP[0])
        noerror = "Isochors intersect"
        label_noerror.configure(text=noerror)
    else: 
        label_deltaT.configure(text="")
        label_deltaP.configure(text="")
    
    plt.close()
    plt.style.use('dark_background')
    plt.rcParams['axes.facecolor'] = '#E0E0E0'
    plt.rcParams['figure.facecolor'] = '#333333'
    plt.rcParams['figure.edgecolor'] = '#2A2A2A'
    fig, ax = plt.subplots(1, figsize=(6.4, 4.5), dpi=104)
    fig.suptitle('Simultaneous pressure and temperature determination by two EoS', fontsize=12)
    ax.plot(dataT1, dataP1 / 1.e9, color="red", label=EoS1nm)
    ax.plot(dataT2, dataP2 / 1.e9, color="blue", label=EoS2nm)
    
    regEos1min = np.polyfit(dataT1min, dataP1min,8)
    regEos1plus = np.polyfit(dataT1plus, dataP1plus,8)
    regEos2min = np.polyfit(dataT2min, dataP2min,8)
    regEos2plus = np.polyfit(dataT2plus, dataP2plus,8)   
    
    x = np.linspace(270,3000,500)
    yEoS1min = regEos1min[0]*x**8+regEos1min[1]*x**7+regEos1min[2]*x**6+regEos1min[3]*x**5+regEos1min[4]*x**4+regEos1min[5]*x**3+regEos1min[6]*x**2+regEos1min[7]*x+regEos1min[8]
    yregEos1plus = regEos1plus[0]*x**8+regEos1plus[1]*x**7+regEos1plus[2]*x**6+regEos1plus[3]*x**5+regEos1plus[4]*x**4+regEos1plus[5]*x**3+regEos1plus[6]*x**2+regEos1plus[7]*x+regEos1plus[8]
    yregEos2min = regEos2min[0]*x**8+regEos2min[1]*x**7+regEos2min[2]*x**6+regEos2min[3]*x**5+regEos2min[4]*x**4+regEos2min[5]*x**3+regEos2min[6]*x**2+regEos2min[7]*x+regEos2min[8]
    yregEos2plus = regEos2plus[0]*x**8+regEos2plus[1]*x**7+regEos2plus[2]*x**6+regEos2plus[3]*x**5+regEos2plus[4]*x**4+regEos2plus[5]*x**3+regEos2plus[6]*x**2+regEos2plus[7]*x+regEos2plus[8]
    
    ax.fill_between(x, yEoS1min / 1.e09, yregEos1plus / 1.e09, color="#FF7F7F", alpha=0.3)
    ax.fill_between(x, yregEos2min / 1.e09, yregEos2plus / 1.e09, color="#0094FF", alpha=0.2)
    
    #Scroll wheel zoom function
    scale = 1.5
    zoom_factory(ax,base_scale = scale)
     
    plt.legend(loc="lower right", frameon=False, labelcolor='black')
    plt.xlim(300, 3000) 
    ax.set_xlabel('Temperature (K)', fontsize=11)
    ax.set_ylabel('Pressure (GPa)', fontsize=11)
    canvas = FigureCanvasTkAgg(fig, master=root)  # A tk.DrawingArea.
    canvas.get_tk_widget().grid(row=0, column=8, rowspan=15, columnspan=15, padx=(0,10)) #,rowspan=20)
    canvas.draw()
    
    toolbarFrame = tk.Frame(master=root)
    toolbarFrame.grid(row=14,column=8, columnspan=15, rowspan=15, sticky=tk.W, padx=(240,0))
    toolbar = NavigationToolbar2Tk(canvas, toolbarFrame)
    toolbar.config(bg="#333333")
    toolbar._message_label.config(bg="#333333", fg="#FFFFFF")
    toolbar.winfo_children()[-2].config(background="#333333")
    toolbar.update()
    
    return 

def polyfiteqnerr(Terr1label, Perr1label):
    P_1 = 'P_1.txt'
    dataP1 = np.loadtxt(P_1, delimiter=',', dtype=float)
    T_1 = 'T_1.txt'
    dataT1 = np.loadtxt(T_1, delimiter=',', dtype=float)
    
    P_2 = 'P_2.txt'
    dataP2 = np.loadtxt(P_2, delimiter=',', dtype=float)
    T_2 = 'T_2.txt'
    dataT2 = np.loadtxt(T_2, delimiter=',', dtype=float)
   
    xi, yi = intersection(dataT1, dataP1 / 1.0e9, dataT2, dataP2 / 1.0e9)
    
    if xi.shape[0] == 1:
        label_T.configure(text=" %.2f" % xi[0])
        label_P.configure(text=" %.3f" % yi[0])
        noerror = "Isochors intersect"
        label_noerror.configure(text=noerror)
    else: 
        label_noerror.configure(text="Isochors do not intersect!  Ignore P-T estimation!")
        label_T.config(text="")
        label_P.config(text="")
    
    P_1h = 'P_1h.txt'
    dataP1h = np.loadtxt(P_1h, delimiter=',', dtype=float)
    T_1h = 'T_1h.txt'
    dataT1h = np.loadtxt(T_1h, delimiter=',', dtype=float)
    
    P_2l = 'P_2l.txt'
    dataP2l = np.loadtxt(P_2l, delimiter=',', dtype=float)
    T_2l = 'T_2l.txt'
    dataT2l = np.loadtxt(T_2l, delimiter=',', dtype=float)
   
    xih, yih = intersection(dataT1h, dataP1h / 1.0e9, dataT2l, dataP2l / 1.0e9)

    if xih.shape[0] == 1:
        noerror = "Isochors intersect"
        label_noerror.configure(text=noerror)
    else: 
        label_noerror.configure(text="Isochors do not intersect!  Ignore P-T estimation!")

    P_1l = 'P_1l.txt'
    dataP1l = np.loadtxt(P_1l, delimiter=',', dtype=float)
    T_1l = 'T_1l.txt'
    dataT1l = np.loadtxt(T_1l, delimiter=',', dtype=float)
    
    P_2h = 'P_2h.txt'
    dataP2h = np.loadtxt(P_2h, delimiter=',', dtype=float)
    T_2h = 'T_2h.txt'
    dataT2h = np.loadtxt(T_2h, delimiter=',', dtype=float)

    xil, yil = intersection(dataT1l, dataP1l / 1.0e9, dataT2h, dataP2h / 1.0e9)

    if xil.shape[0] == 1:
        noerror = "Isochors intersect"
        label_noerror.configure(text=noerror)
    else: 
        label_noerror.configure(text="Isochors do not intersect!  Ignore P-T estimation!")
    
    global Perr1
    global Perr2
    global Terr1
    global Terr2

    Terr1 = abs(xi - xih)
    Terr2 = abs(xi - xil)
    Perr1 = abs(yi - yih)
    Perr2 = abs(yi - yil)
    
    if Terr1.size != 0:
        Terr1 = Terr1[0]
    else: Terr1 = 0.0
    if Perr1.size != 0:
        Perr1 = Perr1[0]
    else: Perr1 = 0.0    
    if Terr2.size != 0:
        Terr2 = Terr2[0]
    else: Terr2 = 0.0    
    if Perr2.size != 0:
        Perr2 = Perr2[0]
    else: Perr2 = 0.0
    
    Terr1label.configure(text="%.2f" % Terr1)
    #Terr2label.config(text="%.2f" % Terr2)
    Perr1label.configure(text="%.3f" % Perr1)
    #Perr2label.config(text="%.2f" % Perr2)
    
    if xi.size != 0:
        with open('data.txt', 'w') as f:
            f.write(f" {xi[0]:.2f}\n")
            f.write(f" {yi[0]:.3f}\n")
            f.write(f" {Terr1:.2f}\n")
            f.write(f" {Perr1:.3f}\n")
        return

def V_V0EoS1(a, a0, V_V0label):
    V0 = float(a0.get())
    V = (float(a.get()))
    V_V0 = V / V0
    V_V0label.config(text=" %.3f" % V_V0)
    return 

def V_V0EoS2(a, a0, V_V0label):
    V0 = float(a0.get()) ** 3.
    V = (float(a.get())) ** 3.
    V_V0 = V / V0
    V_V0label.config(text=" %.3f" % V_V0)
    return 

def on_button():
    if resetfields == 0:
        filename = 'data.txt'
        data = np.loadtxt(filename, delimiter=',', skiprows=0, dtype=str)
        
        label_T = tk.Entry(root, textvariable = data[0], width = 8, font = "Helvetica 13", justify='center')
        label_T.grid(row=11, column=1, columnspan=1, padx=(30, 0), sticky=tk.W)
        label_T.delete(0, 'end')
        label_T.insert(0, data[0])
        label_T.configure(state='readonly', readonlybackground="Lightblue1")
            
        label_P = tk.Entry(root, textvariable = data[1], width = 8, font = "Helvetica 13", justify='center')
        label_P.grid(row=10, column=1, columnspan=1, padx=(30, 0), sticky=tk.W)
        label_P.delete(0, 'end')
        label_P.insert(0, data[1])
        label_P.configure(state='readonly', readonlybackground="Lightblue1")
        
        label_Terr1 = tk.Entry(root, textvariable = data[2], width = 8, font = "Helvetica 13", justify='center')
        label_Terr1.grid(row=11, column=2, columnspan=2, padx=(40, 0), sticky=tk.W)
        label_Terr1.delete(0, 'end')
        label_Terr1.insert(0, data[2])
        label_Terr1.configure(state='readonly', readonlybackground="light yellow")
            
        label_Perr1 = tk.Entry(root, textvariable = data[3], width = 8, font = "Helvetica 13", justify='center')
        label_Perr1.grid(row=10, column=2, columnspan=2, padx=(40, 0), sticky=tk.W)
        label_Perr1.delete(0, 'end')
        label_Perr1.insert(0, data[3])
        label_Perr1.configure(state='readonly', readonlybackground="light yellow")
        
    elif resetfields == 1:
        label_T = tk.Entry(root, textvariable = "", width = 8, font = "Helvetica 13", justify='center')
        label_T.grid(row=11, column=1, columnspan=1, padx=(30, 0), sticky=tk.W)
        label_T.delete(0, 'end')
        label_T.insert(0, "")
        label_T.configure(state='readonly', readonlybackground="Lightblue1")
             
        label_P = tk.Entry(root, textvariable = "", width = 8, font = "Helvetica 13", justify='center')
        label_P.grid(row=10, column=1, columnspan=1, padx=(30, 0), sticky=tk.W)
        label_P.delete(0, 'end')
        label_P.insert(0, "")
        label_P.configure(state='readonly', readonlybackground="Lightblue1")
         
        label_Terr1 = tk.Entry(root, textvariable = "", width = 8, font = "Helvetica 13", justify='center')
        label_Terr1.grid(row=11, column=2, columnspan=2, padx=(40, 0), sticky=tk.W)
        label_Terr1.delete(0, 'end')
        label_Terr1.insert(0, "")
        label_Terr1.configure(state='readonly', readonlybackground="light yellow")
             
        label_Perr1 = tk.Entry(root, textvariable = "", width = 8, font = "Helvetica 13", justify='center')
        label_Perr1.grid(row=10, column=2, columnspan=2, padx=(40, 0), sticky=tk.W)
        label_Perr1.delete(0, 'end')
        label_Perr1.insert(0, "")
        label_Perr1.configure(state='readonly', readonlybackground="light yellow")   
    
def file_save():
    global f
    
    # Define the dictionaries for EoS1Entry and EoS2Entry combinations
    eos_data = {
        EoS1Entry_1: {
            EoS2Entry_1: (EoS1_1, EoS2_1),
            EoS2Entry_2: (EoS1_1, EoS2_2),
            # EoS2Entry_3: (EoS1_1, EoS2_3),
        },
        EoS1Entry_2: {
            EoS2Entry_1: (EoS1_2, EoS2_1),
            EoS2Entry_2: (EoS1_2, EoS2_2),
            # EoS2Entry_3: (EoS1_2, EoS2_3),
        },
        EoS1Entry_3: {
            EoS2Entry_1: (EoS1_3, EoS2_1),
            EoS2Entry_2: (EoS1_3, EoS2_2),
            # EoS2Entry_3: (EoS1_3, EoS2_3),
        },
        # EoS1Entry_4: {
        #     EoS2Entry_1: (EoS1_4, EoS2_1),
        #     EoS2Entry_2: (EoS1_4, EoS2_2),
        #     EoS2Entry_3: (EoS1_4, EoS2_3),
        #     EoS2Entry_4: (EoS1_4, EoS2_4),
        #     EoS2Entry_5: (EoS1_4, EoS2_5)
        # },
        # EoS1Entry_5: {
        #     EoS2Entry_1: (EoS1_5, EoS2_1),
        #     EoS2Entry_2: (EoS1_5, EoS2_2),
        #     EoS2Entry_3: (EoS1_5, EoS2_3),
        #     EoS2Entry_4: (EoS1_5, EoS2_4),
        #     EoS2Entry_5: (EoS1_5, EoS2_5)
        # },
    }
    
    filename = 'data.txt'
    data = np.loadtxt(filename, delimiter=',', skiprows=0, dtype=str)
    f = filedialog.asksaveasfilename(defaultextension=".txt", confirmoverwrite=False)
    if not f:  # asksaveasfile return `None` if dialog closed with "cancel".
        return
    
    selected_entry1 = combobox_var1.get()
    selected_entry2 = combobox_var2.get()
        
    if selected_entry1 in eos_data and selected_entry2 in eos_data[selected_entry1]:
        eos_entry_eos1, eos_entry_eos2 = eos_data[selected_entry1][selected_entry2]
        
        with open(f, "a+") as myfile:
            myfile.write("".join(["p ", "P ", "T ", " ", 
                                  "a0_{}".format(EoS1nm), "a_{}".format(EoS1nm), "esd_{}".format(EoS1nm), "P_{}".format(EoS1nm), "P_esd ", " ", 
                                  "a0_{}".format(EoS2nm), "a_{}".format(EoS2nm), "esd_{}".format(EoS2nm), "P_{}".format(EoS2nm), "P_esd ", " ", 
                                  "P_cross ", "P_esd ", "T_cross ", "T_esd" + '\n']))
            myfile.write("".join(["(bar) ", "(W) ", "(K) ", " ", 
                                  "(\xC5) ", "(\xC5) ", "(\xC5) ", "(GPa) ", "(GPa) ", " ", 
                                  "(\xC5) ", "(\xC5) ", "(\xC5) ", "(GPa) ", "(GPa) ", " ", 
                                  "(GPa) ", "(GPa) ", "(K) ", "(K) " + '\n']))
            myfile.write("".join([str(ePbar.get()), " ", str(ePow.get()), " ", str(entry_T.get()), " ", 
                                  " ", str(a0EoS1.get()), " ", str(aEoS1.get()), " ", str(aEoS1err.get()), " ", str('{:.3f}'.format(eos_entry_eos1.P_EoS1)), " ", str('{:.3f}'.format(eos_entry_eos1.P_esd1)), " ", 
                                  " ", str(a0EoS2.get()), " ", str(aEoS2.get()), " ", str(aEoS2err.get()), " ", str('{:.3f}'.format(eos_entry_eos2.P_EoS2)), " ", str('{:.3f}'.format(eos_entry_eos2.P_esd2)), " ", 
                                  data[1], data[3], data[0], data[2], " ", selected_entry1, " ", selected_entry2]) + '\n')
    return

def file_append():
    filename = 'data.txt'
    data = np.loadtxt(filename, delimiter=',', skiprows=0, dtype=str)
    
    try:
        f
    except NameError:
        f_exists = False
    else:
        f_exists = True
    
    if f_exists:
        # Define the dictionaries for EoS1Entry and EoS2Entry combinations
        eos_data = {
            EoS1Entry_1: {
                EoS2Entry_1: (EoS1_1, EoS2_1),
                EoS2Entry_2: (EoS1_1, EoS2_2),
                # EoS2Entry_3: (EoS1_1, EoS2_3),
            },
            EoS1Entry_2: {
                EoS2Entry_1: (EoS1_2, EoS2_1),
                EoS2Entry_2: (EoS1_2, EoS2_2),
                # EoS2Entry_3: (EoS1_2, EoS2_3),
            },
            EoS1Entry_3: {
                EoS2Entry_1: (EoS1_3, EoS2_1),
                EoS2Entry_2: (EoS1_3, EoS2_2),
                # EoS2Entry_3: (EoS1_3, EoS2_3),
            },
            # EoS1Entry_4: {
            #     EoS2Entry_1: (EoS1_4, EoS2_1),
            #     EoS2Entry_2: (EoS1_4, EoS2_2),
            #     EoS2Entry_3: (EoS1_4, EoS2_3),
            #     EoS2Entry_4: (EoS1_4, EoS2_4),
            #     EoS2Entry_5: (EoS1_4, EoS2_5)
            # },
            # EoS1Entry_5: {
            #     EoS2Entry_1: (EoS1_5, EoS2_1),
            #     EoS2Entry_2: (EoS1_5, EoS2_2),
            #     EoS2Entry_3: (EoS1_5, EoS2_3),
            #     EoS2Entry_4: (EoS1_5, EoS2_4),
            #     EoS2Entry_5: (EoS1_5, EoS2_5)
            # },
        }

        selected_entry1 = combobox_var1.get()
        selected_entry2 = combobox_var2.get()
        
        if selected_entry1 in eos_data and selected_entry2 in eos_data[selected_entry1]:
            eos_entry_eos1, eos_entry_eos2 = eos_data[selected_entry1][selected_entry2]
            
            with open(f, "a+") as myfile:
                myfile.write("".join([str(ePbar.get()), " ", str(ePow.get()), " ", str(entry_T.get()), " ", 
                                      " ", str(a0EoS1.get()), " ", str(aEoS1.get()), " ", str(aEoS1err.get()), " ", str('{:.3f}'.format(eos_entry_eos1.P_EoS1)), " ", str('{:.3f}'.format(eos_entry_eos1.P_esd1)), " ", 
                                      " ", str(a0EoS2.get()), " ", str(aEoS2.get()), " ", str(aEoS2err.get()), " ", str('{:.3f}'.format(eos_entry_eos2.P_EoS2)), " ", str('{:.3f}'.format(eos_entry_eos2.P_esd2)), " ", 
                                      data[1], data[3], data[0], data[2], " ", selected_entry1, " ", selected_entry2]) + '\n')
    else:        
        messagebox.showerror("Error", "Save a file first before you append to it!")
    return

def Pesd(label_Pesd_EoS1, label_Pesd_EoS2):
    # Define the dictionaries for EoS1Entry and EoS2Entry combinations
    eos_data = {
        EoS1Entry_1: {
            EoS2Entry_1: (EoS1_1, EoS2_1),
            EoS2Entry_2: (EoS1_1, EoS2_2),
            # EoS2Entry_3: (EoS1_1, EoS2_3),
        },
        EoS1Entry_2: {
            EoS2Entry_1: (EoS1_2, EoS2_1),
            EoS2Entry_2: (EoS1_2, EoS2_2),
            # EoS2Entry_3: (EoS1_2, EoS2_3),
        },
        EoS1Entry_3: {
            EoS2Entry_1: (EoS1_3, EoS2_1),
            EoS2Entry_2: (EoS1_3, EoS2_2),
            # EoS2Entry_3: (EoS1_3, EoS2_3),
        },
        # EoS1Entry_4: {
        #     EoS2Entry_1: (EoS1_4, EoS2_1),
        #     EoS2Entry_2: (EoS1_4, EoS2_2),
        #     EoS2Entry_3: (EoS1_4, EoS2_3),
        #     EoS2Entry_4: (EoS1_4, EoS2_4),
        #     EoS2Entry_5: (EoS1_4, EoS2_5)
        # },
        # EoS1Entry_5: {
        #     EoS2Entry_1: (EoS1_5, EoS2_1),
        #     EoS2Entry_2: (EoS1_5, EoS2_2),
        #     EoS2Entry_3: (EoS1_5, EoS2_3),
        #     EoS2Entry_4: (EoS1_5, EoS2_4),
        #     EoS2Entry_5: (EoS1_5, EoS2_5)
        # },
    }

    selected_entry1 = combobox_var1.get()
    selected_entry2 = combobox_var2.get()
    
    if selected_entry1 in eos_data and selected_entry2 in eos_data[selected_entry1]:
        eos_entry_eos1, eos_entry_eos2 = eos_data[selected_entry1][selected_entry2]
        
    label_Pesd_EoS1.configure(text=" %.3f" % eos_entry_eos1.P_esd1)
    label_Pesd_EoS2.configure(text=" %.3f" % eos_entry_eos2.P_esd2)
    return

def changeText1():  
    buttonSave.configure(width = 100, text = ' Saved! ', fg_color="#144870")

def changeText():  
    buttonapp.configure(width = 100, text = ' Saved! ')
    buttonapp.after(3000,lambda: changeTextback())
    
def changeTextback():
    buttonapp.configure(width = 100, text = 'Append') 

def selected():
    # Define the dictionaries for EoS1Entry and EoS2Entry combinations
    eos_functions = {
        EoS1Entry_1: {
            EoS2Entry_1: (call_result_EoS1_1, call_result_EoS2_1),
            EoS2Entry_2: (call_result_EoS1_1, call_result_EoS2_2),
            # EoS2Entry_3: (call_result_EoS1_1, call_result_EoS2_3),
        },
        EoS1Entry_2: {
            EoS2Entry_1: (call_result_EoS1_2, call_result_EoS2_1),
            EoS2Entry_2: (call_result_EoS1_2, call_result_EoS2_2),
            # EoS2Entry_3: (call_result_EoS1_2, call_result_EoS2_3),
        },
        EoS1Entry_3: {
            EoS2Entry_1: (call_result_EoS1_3, call_result_EoS2_1),
            EoS2Entry_2: (call_result_EoS1_3, call_result_EoS2_2),
            # EoS2Entry_3: (call_result_EoS1_3, call_result_EoS2_3),
        },
        # EoS1Entry_4: {
        #     EoS2Entry_1: (call_result_EoS1_4, call_result_EoS2_1),
        #     EoS2Entry_2: (call_result_EoS1_4, call_result_EoS2_2),
        #     EoS2Entry_3: (call_result_EoS1_4, call_result_EoS2_3),
        #     EoS2Entry_4: (call_result_EoS1_4, call_result_EoS2_4),
        #     EoS2Entry_5: (call_result_EoS1_4, call_result_EoS2_5)
        # },
        # EoS1Entry_5: {
        #     EoS2Entry_1: (call_result_EoS1_5, call_result_EoS2_1),
        #     EoS2Entry_2: (call_result_EoS1_5, call_result_EoS2_2),
        #     EoS2Entry_3: (call_result_EoS1_5, call_result_EoS2_3),
        #     EoS2Entry_4: (call_result_EoS1_5, call_result_EoS2_4),
        #     EoS2Entry_5: (call_result_EoS1_5, call_result_EoS2_5)
        # },
    }

    eos_errors = {
        EoS1Entry_1: {
            EoS2Entry_1: (call_result_EoS1errhigh_1, call_result_EoS1errlow_1, call_result_EoS2errhigh_1, call_result_EoS2errlow_1),
            EoS2Entry_2: (call_result_EoS1errhigh_1, call_result_EoS1errlow_1, call_result_EoS2errhigh_2, call_result_EoS2errlow_2),
            # EoS2Entry_3: (call_result_EoS1errhigh_1, call_result_EoS1errlow_1, call_result_EoS2errhigh_3, call_result_EoS2errlow_3),
        },
        EoS1Entry_2: {
            EoS2Entry_1: (call_result_EoS1errhigh_2, call_result_EoS1errlow_2, call_result_EoS2errhigh_1, call_result_EoS2errlow_1),
            EoS2Entry_2: (call_result_EoS1errhigh_2, call_result_EoS1errlow_2, call_result_EoS2errhigh_2, call_result_EoS2errlow_2),
            # EoS2Entry_3: (call_result_EoS1errhigh_2, call_result_EoS1errlow_2, call_result_EoS2errhigh_3, call_result_EoS2errlow_3),
        },
        EoS1Entry_3: {
            EoS2Entry_1: (call_result_EoS1errhigh_3, call_result_EoS1errlow_3, call_result_EoS2errhigh_1, call_result_EoS2errlow_1),
            EoS2Entry_2: (call_result_EoS1errhigh_3, call_result_EoS1errlow_3, call_result_EoS2errhigh_2, call_result_EoS2errlow_2),
            # EoS2Entry_3: (call_result_EoS1errhigh_3, call_result_EoS1errlow_3, call_result_EoS2errhigh_3, call_result_EoS2errlow_3),
        },
        # EoS1Entry_4: {
        #     EoS2Entry_1: (call_result_EoS1errhigh_4, call_result_EoS1errlow_4, call_result_EoS2errhigh_1, call_result_EoS2errlow_1),
        #     EoS2Entry_2: (call_result_EoS1errhigh_4, call_result_EoS1errlow_4, call_result_EoS2errhigh_2, call_result_EoS2errlow_2),
        #     EoS2Entry_3: (call_result_EoS1errhigh_4, call_result_EoS1errlow_4, call_result_EoS2errhigh_3, call_result_EoS2errlow_3),
        #     EoS2Entry_4: (call_result_EoS1errhigh_4, call_result_EoS1errlow_4, call_result_EoS2errhigh_4, call_result_EoS2errlow_4),
        #     EoS2Entry_5: (call_result_EoS1errhigh_4, call_result_EoS1errlow_4, call_result_EoS2errhigh_5, call_result_EoS2errlow_5)
        # },
        # EoS1Entry_5: {
        #     EoS2Entry_1: (call_result_EoS1errhigh_5, call_result_EoS1errlow_5, call_result_EoS2errhigh_1, call_result_EoS2errlow_1),
        #     EoS2Entry_2: (call_result_EoS1errhigh_5, call_result_EoS1errlow_5, call_result_EoS2errhigh_2, call_result_EoS2errlow_2),
        #     EoS2Entry_3: (call_result_EoS1errhigh_5, call_result_EoS1errlow_5, call_result_EoS2errhigh_3, call_result_EoS2errlow_3),
        #     EoS2Entry_4: (call_result_EoS1errhigh_5, call_result_EoS1errlow_5, call_result_EoS2errhigh_4, call_result_EoS2errlow_4),
        #     EoS2Entry_5: (call_result_EoS1errhigh_5, call_result_EoS1errlow_5, call_result_EoS2errhigh_5, call_result_EoS2errlow_5)
        # },
    }

    # Retrieve the selected entries
    selected_entry1 = combobox_var1.get()
    selected_entry2 = combobox_var2.get()

    if selected_entry1 in eos_functions and selected_entry2 in eos_functions[selected_entry1]:
        entry_function_eos1, entry_function_eos2 = eos_functions[selected_entry1][selected_entry2]

        high_error_func_eos1, low_error_func_eos1, high_error_func_eos2, low_error_func_eos2 = eos_errors[selected_entry1][selected_entry2]

        common_functions = [
            entry_function_eos1,
            entry_function_eos2,
            high_error_func_eos1,
            low_error_func_eos1,
            high_error_func_eos2,
            low_error_func_eos2,
            EoSError,
            call_result_EoS,
            call_result_V_V01,
            call_result_V_V02,
            call_result_Pesd,
            on_button
        ]

        for func in common_functions:
            func()

def explorer():
    try:
        f
    except NameError:
        f_exists = False
    else:
        f_exists = True
    
    if f_exists:
        subprocess.run(['explorer', os.path.realpath(f)])
    else:
        messagebox.showerror("Error", "Save a file first.")
    
def explorerpath():
    try:
        f
    except NameError:
        f_exists = False
    else:
        f_exists = True
    
    if f_exists:
        file = os.path.realpath(f)
        filedir = os.path.split(file)
        subprocess.run(['explorer', filedir[0]])
    else:
        messagebox.showerror("Error", "Save a file first.")
        
def combobox_callback(choice):
    #If deviating in any papers, enter a0 or V0 for all phases here according to the EoS.
    print("combobox dropdown clicked:", choice)
    if choice == EoS1Entry_1:
        entry_a0EoS1.delete(0, 'end')
        entry_a0EoS1.insert(0, 255.1)
    if choice == EoS1Entry_2:
        entry_a0EoS1.delete(0, 'end')
        entry_a0EoS1.insert(0, 255.45)
    if choice == EoS1Entry_3:
        entry_a0EoS1.delete(0, 'end')
        entry_a0EoS1.insert(0, 255.05)
        
    if choice == EoS2Entry_1:
        entry_a0EoS2.delete(0, 'end')
        entry_a0EoS2.insert(0, 2.8665)
    if choice == EoS2Entry_2:
        entry_a0EoS2.delete(0, 'end')
        entry_a0EoS2.insert(0, 2.8654)        
        #...

""" 
GUI CustomTkinter, do not modify
"""

customtkinter.set_appearance_mode("dark")  # Modes: system (default), light, dark
customtkinter.set_default_color_theme("blue")  # Themes: blue (default), dark-blue, green
    
root = customtkinter.CTk()  
#root.tk.call('tk', 'scaling', 1.4)
root.geometry('1420x556')     
root.resizable(width=False, height=False)
root.title(EoStitle)  

#Row 0
label_Tem = customtkinter.CTkLabel(root, text="Enter lattice parameters")
label_Tem.grid(row=0, column=1, sticky=tk.W, columnspan=6, pady=(5,0), padx=(10, 0))
label_Tem.configure(font=('Helvetica', 18, 'bold'))

label_Tem = customtkinter.CTkLabel(root, text_color="#999999", text="v1.3 R. Farla \u2014 Powered by Burnman")
label_Tem.grid(row=0, column=6, sticky=tk.W, columnspan=2, pady=(12,0), padx=(0, 0))
label_Tem.configure(font=('Helvetica', 12, 'bold'))

img = customtkinter.CTkImage(dark_image=Image.open("burnjack-square.png"), size=(40, 40))  
image_label = customtkinter.CTkLabel(root, image=img, text="")  # display image with a CTkLabel
image_label.grid(row=0, column=7, columnspan=2, pady=(5,0))

#Row 1
label_EoS1 = customtkinter.CTkLabel(root, text=EoS1nm)
label_EoS1.grid(row=1, column=1, padx=(10, 0), pady=(5,0), sticky=tk.W)
label_EoS1.configure(text_color="#FF0000", font=('Helvetica', 16, 'bold'))

#Row 2
label_a0EoS1 = customtkinter.CTkLabel(root, text=EoS1unit0)
label_a0EoS1.grid(row=2, column=1, sticky=tk.W, padx=(10, 5))
label_a0EoS1.configure(font=('Helvetica', 14, 'bold'))
label_aEoS1 = customtkinter.CTkLabel(root, text=EoS1unit)
label_aEoS1.grid(row=2, column=2, sticky=tk.W, padx=(5, 10))
label_aEoS1.configure(font=('Helvetica', 14, 'bold'))
label_aEoS1err = customtkinter.CTkLabel(root, text=EoS1uniterr)
label_aEoS1err.grid(row=2, column=3, sticky=tk.W, padx=(10, 0))
label_aEoS1err.configure(font=('Helvetica', 14, 'bold'))
label_V_V0 = customtkinter.CTkLabel(root, text="V/V0")
label_V_V0.grid(row=2, column=4, padx=(0,5))
label_V_V0.configure(font=('Helvetica', 14, 'bold'))
label_Tem = customtkinter.CTkLabel(root, text="P (GPa)")
label_Tem.grid(row=2, column=5, sticky=tk.W)
label_Tem.configure(font=('Helvetica', 14, 'bold'))
label_Pesd = customtkinter.CTkLabel(root, text="P esd")
label_Pesd.grid(row=2, column=6, sticky=tk.W)
label_Pesd.configure(font=('Helvetica', 14, 'bold'))
label_EoS = customtkinter.CTkLabel(root, text="EoS (* preferred)")
label_EoS.grid(row=2, column=7, sticky=tk.W, padx=(5,0))
label_EoS.configure(font=('Helvetica', 14, 'bold'))

#Row3
a0EoS1 = tk.StringVar()
entry_a0EoS1 = tk.Entry(root, textvariable=a0EoS1, width = 7, bg="#616161", justify='center', font = "Helvetica 12")
entry_a0EoS1.grid(row=3, column=1, sticky=tk.W, padx=(10, 5)) 
entry_a0EoS1.insert(0, EoS1a0)

aEoS1 = tk.StringVar()
entry_aEoS1 = tk.Entry(root, textvariable=aEoS1, width = 7, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_aEoS1.grid(row=3, column=2, sticky=tk.E, padx=(5, 5)) 
entry_aEoS1.insert(0, EoS1a)

aEoS1err = tk.StringVar()
entry_aEoS1err = tk.Entry(root, textvariable=aEoS1err, width = 7, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_aEoS1err.grid(row=3, column=3, sticky=tk.W, padx=(5, 0)) 
entry_aEoS1err.insert(0, EoS1aerr)

label_VV01 = tk.Label(root, width = 7, bg = "#D3D3D3", font = "Helvetica 12")
label_VV01.grid(row=3, column=4, sticky=tk.E, padx=(40,15))

label_PEoS1 = tk.Label(root, width = 7, bg = "Lightblue1", font = "Helvetica 12")
label_PEoS1.grid(row=3, column=5, sticky=tk.W)

label_Pesd_EoS1 = tk.Label(root, width = 7, bg = "light yellow", font = "Helvetica 12")
label_Pesd_EoS1.grid(row=3, column=6, sticky=tk.W, padx=(2, 0))

#Row4
label_EoS2 = customtkinter.CTkLabel(root, text=EoS2nm)
label_EoS2.grid(row=4, column=1, padx=(10, 0), pady=(10,0), sticky=tk.W, columnspan=4)
label_EoS2.configure(text_color="#1C94CF", font=('Helvetica', 16, 'bold'))

#Row5
label_a0EoS2 = customtkinter.CTkLabel(root, text=EoS2unit0)
label_a0EoS2.grid(row=5, column=1, sticky=tk.W, padx=(10, 5))
label_a0EoS2.configure(font=('Helvetica', 14, 'bold'))
label_aEoS2 = customtkinter.CTkLabel(root, text=EoS2unit)
label_aEoS2.grid(row=5, column=2, sticky=tk.W, padx=(5, 10))
label_aEoS2.configure(font=('Helvetica', 14, 'bold'))
label_aEoS2err = customtkinter.CTkLabel(root, text=EoS2uniterr)
label_aEoS2err.grid(row=5, column=3, sticky=tk.W, padx=(10, 0))
label_aEoS2err.configure(font=('Helvetica', 14, 'bold'))
label_V_V0 = customtkinter.CTkLabel(root, text="V/V0")
label_V_V0.grid(row=5, column=4, padx=(0,5))
label_V_V0.configure(font=('Helvetica', 14, 'bold'))
label_Tem = customtkinter.CTkLabel(root, text="P (GPa)")
label_Tem.grid(row=5, column=5, sticky=tk.W)
label_Tem.configure(font=('Helvetica', 14, 'bold'))
label_Pesd = customtkinter.CTkLabel(root, text="P esd")
label_Pesd.grid(row=5, column=6, sticky=tk.W, padx=(2, 0))
label_Pesd.configure(font=('Helvetica', 14, 'bold'))
label_EoS = customtkinter.CTkLabel(root, text="EoS (* preferred)")
label_EoS.grid(row=5, column=7, sticky=tk.W, padx=(5,0))
label_EoS.configure(font=('Helvetica', 14, 'bold'))

#Row6
a0EoS2 = tk.StringVar()
entry_a0EoS2 = tk.Entry(root, textvariable=a0EoS2, width = 7, bg="#616161", justify='center', font = "Helvetica 12")
entry_a0EoS2.grid(row=6, column=1, sticky=tk.W, padx=(10, 5)) 
entry_a0EoS2.insert(0, EoS2a0)

aEoS2 = tk.StringVar()
entry_aEoS2 = tk.Entry(root, textvariable=aEoS2, width = 7, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_aEoS2.grid(row=6, column=2, sticky=tk.E, padx=(5, 5)) 
entry_aEoS2.insert(0, EoS2a)

aEoS2err = tk.StringVar()
entry_aEoS2err = tk.Entry(root, textvariable=aEoS2err, width = 7, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_aEoS2err.grid(row=6, column=3, sticky=tk.W, padx=(5, 0)) 
entry_aEoS2err.insert(0, EoS2aerr)

label_VV02 = tk.Label(root, width = 7, bg = "#D3D3D3", font = "Helvetica 12")
label_VV02.grid(row=6, column=4, sticky=tk.E, padx=(40,15))

label_PEoS2 = tk.Label(root, width = 7, bg = "Lightblue1", font = "Helvetica 12")
label_PEoS2.grid(row=6, column=5, sticky=tk.W)

label_Pesd_EoS2 = tk.Label(root, width = 7, bg = "light yellow", font = "Helvetica 12")
label_Pesd_EoS2.grid(row=6, column=6, sticky=tk.W, padx=(2, 0))

#Row7
label_calc = customtkinter.CTkLabel(root, text="T  =   ")
label_calc.grid(row=7, column=1, columnspan=4, pady=(15,10), padx=(5,0), sticky=tk.E)
label_calc.configure(font=('Helvetica', 14, 'bold'))

label_calc = customtkinter.CTkLabel(root, text=u"\u00B1")
label_calc.grid(row=7, column=5, columnspan=1, pady=(15,10), padx=(0,3), sticky=tk.E)
label_calc.configure(font=('Helvetica', 14, 'bold'))

T = tk.StringVar()
entry_T = tk.Entry(root, textvariable=T, width = 7, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_T.grid(row=7, column=5, padx=(1, 15), pady=(15,10)) 
entry_T.insert(0, "300")

Tesd = tk.StringVar()
entry_Tesd = tk.Entry(root, textvariable=Tesd, width = 4, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_Tesd.grid(row=7, column=6, padx=(2, 15), pady=(15,10), sticky=tk.W) 
entry_Tesd.insert(0, "10")

label_calc = customtkinter.CTkLabel(root, text="K")
label_calc.grid(row=7, column=6, columnspan=1, pady=(15,10), padx=(47,0), sticky=tk.W)
label_calc.configure(font=('Helvetica', 14, 'bold'))

buttonCal = customtkinter.CTkButton(root, text="Calculate...!", command=selected)
buttonCal.grid(row=7, column=1, pady=(5,0), sticky=tk.W, padx=(10, 5), columnspan=3)  

#Row9
label_Result = customtkinter.CTkLabel(root, text="Joint P-T estimation")
label_Result.grid(row=9, column=1, columnspan=4, sticky=tk.W, pady=(10,5), padx=(10,0))
label_Result.configure(font=('Helvetica', 18, 'bold'))

#Row10
label_Press = customtkinter.CTkLabel(root, text="P" )
label_Press.grid(row=10, column=1, pady=(0, 5), padx=(10,0), sticky=tk.W)
label_Press.configure(font=('Helvetica', 14, 'bold'))
label_Press = customtkinter.CTkLabel(root, text="GPa" )
label_Press.grid(row=10, column=3, pady=(5, 5), padx=(45,0), sticky=tk.W)
label_Press.configure(font=('Helvetica', 14, 'bold'))
label_Press = customtkinter.CTkLabel(root, text=u"\u00B1" )
label_Press.grid(row=10, column=2, pady=(5, 5), padx=(15,0), sticky=tk.W)
label_Press.configure(font=('Helvetica', 14, 'bold'))
label_P = tk.Entry(root, width = 8, bg = "Lightblue1", font = "Helvetica 13", justify='center')
label_P.grid(row=10, column=1, pady=(5, 5), padx=(30, 0), sticky=tk.W)
label_Perr1 = tk.Entry(root, width = 8, bg = "light yellow", font = "Helvetica 13", justify='center')
label_Perr1.grid(row=10, column=2, sticky=tk.W, padx=(40, 0), columnspan=2)

#Row11
label_Temp = customtkinter.CTkLabel(root, text="T" )
label_Temp.grid(row=11, column=1, pady=(0, 5), padx=(10,0), sticky=tk.W)
label_Temp.configure(font=('Helvetica', 14, 'bold'))
label_Temp = customtkinter.CTkLabel(root, text="K" )
label_Temp.grid(row=11, column=3, pady=(5, 5), padx=(45,0), sticky=tk.W)
label_Temp.configure(font=('Helvetica', 14, 'bold'))
label_Temp = customtkinter.CTkLabel(root, text=u"\u00B1" )
label_Temp.grid(row=11, column=2, padx=(15,0), sticky=tk.W)
label_Temp.configure(font=('Helvetica', 14, 'bold'))
label_T = tk.Entry(root, width = 8, bg = "Lightblue1", font = "Helvetica 13", justify='center')
label_T.grid(row=11, column=1, sticky=tk.W, padx=(30, 0)) 
label_Terr1 = tk.Entry(root, width = 8, bg = "light yellow", font = "Helvetica 13", justify='center')
label_Terr1.grid(row=11, column=2, sticky=tk.W, padx=(40, 0), columnspan=2)  

#Row12
buttonSave = customtkinter.CTkButton(root, width = 100, text="Save file", command=lambda:[file_save(), changeText1()]) #file_save(), changeText1()
buttonSave.grid(row=10, column=6, pady=(5,5), sticky=tk.W, padx=(8, 0), columnspan=1)  

buttonapp = customtkinter.CTkButton(root, width = 100, text="Append", command=lambda:[file_append(), changeText()]) #file_append(), changeText()
buttonapp.grid(row=7, column=2, pady=(10,5), sticky=tk.W, padx=(50, 0), columnspan=2)  

buttonexpl = customtkinter.CTkButton(root, width = 100, text="Open file", command=explorer) #explorer
buttonexpl.grid(row=10, column=7, pady=(5,5), sticky=tk.W, padx=(12, 0), columnspan=1)  

#buttonexpl = customtkinter.CTkButton(root, width = 100, text="Open directory", command=explorerpath) #explorer
#buttonexpl.grid(row=11, column=7, pady=(5,5), sticky=tk.W, padx=(8, 0), columnspan=1)  

label_lvp = customtkinter.CTkLabel(root, text="Press load & power:" )
label_lvp.grid(row=9, column=4, pady=(8, 0), padx=(40,0), columnspan=2, sticky=tk.W)
label_lvp.configure(font=('Helvetica', 14, 'bold'))

ePbar = tk.StringVar()
entry_ePbar = tk.Entry(root, textvariable=ePbar, width = 7, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_ePbar.grid(row=10, column=4, sticky=tk.W, padx=(40, 0), pady=(0, 0)) 
entry_ePbar.insert(0, Pbar)

label_oilP = customtkinter.CTkLabel(root, text="bar / MN" )
label_oilP.grid(row=10, column=5, sticky=tk.W, padx=(0,0))
label_oilP.configure(font=('Helvetica', 13, 'bold'))

ePow = tk.StringVar()
entry_ePow = tk.Entry(root, textvariable=ePow, width = 7, bg="#D3D3D3", justify='center', font = "Helvetica 12")
entry_ePow.grid(row=11, column=4, sticky=tk.W, padx=(40, 0)) 
entry_ePow.insert(0, Pow)

label_Pow = customtkinter.CTkLabel(root, text="W / \u00b0C" )
label_Pow.grid(row=11, column=5, padx=(0,0), sticky=tk.W)
label_Pow.configure(font=('Helvetica', 13, 'bold'))

label_noerror = customtkinter.CTkLabel(root, width = 425, height = 20, corner_radius=7, text="", fg_color = "#D3D3D3", text_color="#000000")
label_noerror.grid(row=12, column=1, columnspan=6, sticky=tk.W, pady=(15,0), padx=(10,0))
label_noerror.configure(font=('Helvetica', 12, 'bold'))

label_Info = customtkinter.CTkLabel(root, justify="left", text_color="#999999", text="1. The parameter a0 (or V0) is part of the EoS, modify at your own risk." )
label_Info.grid(row=13, column=1, pady=(10,0), padx=(10,0), columnspan=6, sticky=tk.W)
label_Info.configure(font=('Helvetica', 12, 'bold'))

label_Info = customtkinter.CTkLabel(root, justify="left", text_color="#999999", text="2. A PVT correlation matrix is used to calculate uncertainties in the pressure for each phase, and do not take into account \n the uncertainties in the calibrated equation of state. The errors in the joint PT calculation are further simplified, \n i.e. the errors in P & T are calculated from the differences between the largest and smallest unit cell volumes, as visualised." )
label_Info.grid(row=14, column=1, padx=(10,0), columnspan=7, sticky=tk.W)
label_Info.configure(font=('Helvetica', 12, 'bold'))

#Other (not displayed)
label_Pressure_EoS1 = tk.Label(root, width = 6, bg = "light yellow")
label_Temperature_EoS1 = tk.Label(root, width = 6, bg = "light yellow")
label_Pressure_EoS2 = tk.Label(root, width = 6, bg = "light yellow")
label_Temperature_EoS2 = tk.Label(root, width = 6, bg = "light yellow")
label_Pmin = tk.Label(root, width = 6, bg = "floral white")
label_Tmin = tk.Label(root, width = 6, bg = "floral white")
label_Pmax = tk.Label(root, width = 6, bg = "bisque")
label_Tmax = tk.Label(root, width = 6, bg = "bisque")
label_deltaP = tk.Label(root, width = 6, bg = "light yellow")
label_deltaT = tk.Label(root, width = 6, bg = "light yellow")
unc1 = tk.StringVar()
entry_unc1 = tk.Entry(root, textvariable=unc1, width = 8)
entry_unc1.insert(0, "0.05")
unc2 = tk.StringVar()
entry_unc2 = tk.Entry(root, textvariable=unc2, width = 8)
entry_unc2.insert(0, "0.05")

#Other (not displayed)
label_PEoS1err = tk.Label(root, width = 6, bg = "light yellow")
label_PEoS2err = tk.Label(root, width = 6, bg = "light yellow")
label_Pressure_EoS1err = tk.Label(root, width = 6, bg = "light yellow")
label_Temperature_EoS1err = tk.Label(root, width = 6, bg = "light yellow")
label_Pressure_EoS2err = tk.Label(root, width = 6, bg = "light yellow")
label_Temperature_EoS2err = tk.Label(root, width = 6, bg = "light yellow")

"""
Edit these lines
"""
    
# EoS choices for Phase 1    
combobox_var1 = customtkinter.StringVar(value=EoS1Entry_1)
combobox = customtkinter.CTkComboBox(root, border_width=0, values=[EoS1Entry_1, EoS1Entry_2, EoS1Entry_3],
                                     command=combobox_callback, variable=combobox_var1)
combobox_var1.set(EoS1Entry_1)
combobox.grid(row=3, column=7, padx=(0,15))

# EoS choices for Phase 2
combobox_var2 = customtkinter.StringVar(value=EoS2Entry_1)
combobox = customtkinter.CTkComboBox(root, border_width=0, values=[EoS2Entry_1, EoS2Entry_2],
                                     command=combobox_callback, variable=combobox_var2)
combobox_var2.set(EoS2Entry_1)
combobox.grid(row=6, column=7, padx=(0,15))

# Calculations
call_result_EoS1_1 = partial(EoS1_1.EoS1, aEoS1, a0EoS1, T, label_PEoS1, label_Pressure_EoS1, label_Temperature_EoS1)
call_result_EoS1_2 = partial(EoS1_2.EoS1, aEoS1, a0EoS1, T, label_PEoS1, label_Pressure_EoS1, label_Temperature_EoS1)
call_result_EoS1_3 = partial(EoS1_3.EoS1, aEoS1, a0EoS1, T, label_PEoS1, label_Pressure_EoS1, label_Temperature_EoS1)
#call_result_EoS1_4 = partial(EoS1_4.EoS1, aEoS1, a0EoS1, T, label_PEoS1, label_Pressure_EoS1, label_Temperature_EoS1)
#call_result_EoS1_5 = partial(EoS1_5.EoS1, aEoS1, a0EoS1, T, label_PEoS1, label_Pressure_EoS1, label_Temperature_EoS1)

call_result_EoS2_1 = partial(EoS2_1.EoS2, aEoS2, a0EoS2, T, label_PEoS2, label_Pressure_EoS2, label_Temperature_EoS2) 
call_result_EoS2_2 = partial(EoS2_2.EoS2, aEoS2, a0EoS2, T, label_PEoS2, label_Pressure_EoS2, label_Temperature_EoS2)
# call_result_EoS2_3 = partial(EoS2_3.EoS2, aEoS2, a0EoS2, T, label_PEoS2, label_Pressure_EoS2, label_Temperature_EoS2)
# call_result_EoS2_4 = partial(EoS2_4.EoS2, aEoS2, a0EoS2, T, label_PEoS2, label_Pressure_EoS2, label_Temperature_EoS2)
# call_result_EoS2_5 = partial(EoS2_5.EoS2, aEoS2, a0EoS2, T, label_PEoS2, label_Pressure_EoS2, label_Temperature_EoS2)

call_result_EoS1errhigh_1 = partial(EoS1_1.EoS1high, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err, Tesd)
call_result_EoS1errhigh_2 = partial(EoS1_2.EoS1high, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err, Tesd)
call_result_EoS1errhigh_3 = partial(EoS1_3.EoS1high, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err, Tesd)
#call_result_EoS1errhigh_4 = partial(EoS1_4.EoS1high, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err, Tesd)
#call_result_EoS1errhigh_5 = partial(EoS1_5.EoS1high, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err, Tesd)

call_result_EoS2errhigh_1 = partial(EoS2_1.EoS2high, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err, Tesd)
call_result_EoS2errhigh_2 = partial(EoS2_2.EoS2high, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err, Tesd)
# call_result_EoS2errhigh_3 = partial(EoS2_3.EoS2high, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err, Tesd)
# call_result_EoS2errhigh_4 = partial(EoS2_4.EoS2high, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err, Tesd)
# call_result_EoS2errhigh_5 = partial(EoS2_5.EoS2high, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err, Tesd)

call_result_EoS1errlow_1 = partial(EoS1_1.EoS1low, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err)
call_result_EoS1errlow_2 = partial(EoS1_2.EoS1low, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err)
call_result_EoS1errlow_3 = partial(EoS1_3.EoS1low, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err)
#call_result_EoS1errlow_4 = partial(EoS1_4.EoS1low, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err)
#call_result_EoS1errlow_5 = partial(EoS1_5.EoS1low, aEoS1, aEoS1err, a0EoS1, T, label_PEoS1err, label_Pressure_EoS1err, label_Temperature_EoS1err)

call_result_EoS2errlow_1 = partial(EoS2_1.EoS2low, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err)  
call_result_EoS2errlow_2 = partial(EoS2_2.EoS2low, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err)
# call_result_EoS2errlow_3 = partial(EoS2_3.EoS2low, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err)  
# call_result_EoS2errlow_4 = partial(EoS2_4.EoS2low, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err)
# call_result_EoS2errlow_5 = partial(EoS2_5.EoS2low, aEoS2, aEoS2err, a0EoS2, T, label_PEoS2err, label_Pressure_EoS2err, label_Temperature_EoS2err)

call_recalcP_EoS1_1 = partial(EoS1_1.open_file, a0EoS1, Tesd)
call_recalcP_EoS1_2 = partial(EoS1_2.open_file, a0EoS1, Tesd)
#call_recalcP_EoS1_3 = partial(EoS1_3.open_file, a0EoS1, Tesd)
#call_recalcP_EoS1_4 = partial(EoS1_4.open_file, a0EoS1, Tesd)
#call_recalcP_EoS1_5 = partial(EoS1_5.open_file, a0EoS1, Tesd)

call_recalcP_EoS2_1 = partial(EoS2_1.open_file, a0EoS2, Tesd)
call_recalcP_EoS2_2 = partial(EoS2_2.open_file, a0EoS2, Tesd)
#call_recalcP_EoS2_3 = partial(EoS2_3.open_file, a0EoS2, Tesd)
#call_recalcP_EoS2_4 = partial(EoS2_4.open_file, a0EoS2, Tesd)
#call_recalcP_EoS2_5 = partial(EoS2_5.open_file, a0EoS2, Tesd)

# Import and process data
buttonImport = customtkinter.CTkButton(root, width = 100, text="Import & calc. pressures for all EoS", command=lambda:[open_file(), call_recalcP_EoS1_1(), call_recalcP_EoS1_2(), call_recalcP_EoS2_1(), call_recalcP_EoS2_2()]) #Add more entries if more EoS are available
buttonImport.grid(row=11, column=6, pady=(5,5), sticky=tk.W, padx=(8, 0), columnspan=2)  

label_Info = customtkinter.CTkLabel(root, justify="left", text_color="#999999", text="Required data format: \nT a1 a1_esd V1 V1_esd rho1 ... \na2 a2_esd V2 V2_esd rho2" )
label_Info.grid(row=12, column=6, pady=(0,0), padx=(10,0), columnspan=6, sticky=tk.W)
label_Info.configure(font=('Helvetica', 12, 'bold'))

"""
Do not modify these last lines
"""

EoSError = partial(polyfiteqnerr, label_Terr1, label_Perr1)

call_result_EoS = partial(polyfiteqn, label_T, label_P, label_Tmin, label_Pmin, label_Tmax, label_Pmax, label_deltaT, label_deltaP, unc1, unc2, label_noerror)
call_result_V_V01 = partial(V_V0EoS1, aEoS1, a0EoS1, label_VV01)
call_result_V_V02 = partial(V_V0EoS2, aEoS2, a0EoS2, label_VV02)
call_result_Pesd = partial(Pesd, label_Pesd_EoS1, label_Pesd_EoS2)

#Draw plot area
plt.style.use('dark_background')
plt.rcParams['axes.facecolor'] = '#E0E0E0'
plt.rcParams['figure.facecolor'] = '#333333'
plt.rcParams['figure.edgecolor'] = '#2A2A2A'

canvas = tk.Canvas(master=root, width=700, height=555) 
canvas.config(bg = "#333333", bd=0, highlightthickness=0, relief='ridge') 
canvas.grid(row=0, column=8, columnspan=7, rowspan=18, padx=(0,10), pady=(0,0))

fig, ax = plt.subplots(1, figsize=(6.4, 4.5), dpi=104)
fig.suptitle('Simultaneous pressure and temperature determination by two EoS', fontsize=12)
ax.set_xlabel('Temperature (K)', fontsize=11)
ax.set_ylabel('Pressure (GPa)', fontsize=11)
canvas = FigureCanvasTkAgg(fig, master=root)  # A tk.DrawingArea.
canvas.get_tk_widget().grid(row=0, column=8, columnspan=15, rowspan=15, padx=(0,10))
canvas.draw()
    
toolbarFrame = tk.Frame(master=root)
toolbarFrame.grid(row=14,column=8, columnspan=15, rowspan=15, sticky=tk.W, padx=(240,0))
toolbar = NavigationToolbar2Tk(canvas, toolbarFrame)
toolbar.config(bg="#333333")
toolbar._message_label.config(bg="#333333", fg="#FFFFFF")
toolbar.winfo_children()[-2].config(background="#333333")
toolbar.update()

root.protocol("WM_DELETE_WINDOW", close)
root.mainloop()