## EosCross

A python application to jointly determine pressure and temperature from in-situ x-ray diffraction (XRD) data. This tool requires knowledge of XRD acquisition at high-pressure synchrotron beamlines, such as the end-station P61B at PETRA III, DESY where this software was developed. Only use this on XRD data collected from intimately-mixed powders of two materials, referred to as PT calibrants inside the hotzone of a high-pressure assembly. You will not get meaningful results if the two calibrants are not in the same location in the HPHT assembly.

The tool uses Burnman (https://geodynamics.github.io/burnman/) for the calculations and its mineral database. If you use EosCross in your publications, please cite the following paper: https://doi.org/10.1107/S1600577523004538 and the ones listed on the Burnman website. 

## Version history

- Version 1.0  
   - Not available anymore
- Version 1.1  
   - First upload to Gitlab, accompanied with publication. Can still be downloaded from a side branch.
- Version 1.2  
   - New option to save a txt file of *all* information on screen for a cross-PT measurement, and append subsequent measurements into the same file. 
   - App was updated to be compatible with the latest versions of Burnman and many other dependencies (e.g. customtkinter).
- Version 1.3  
   - New launcher
   - Many materials (calibrants) were added in Burnman v2.*. EosCross will now use these instead.  
   - Over 70 material pairs for joint PT estimation (or P estimation at given temperature) available.
   - PT calculations can be exported to txt file.
   - Supports batch processing of pressures using all available EoS by loading a file containing the lattice parameters at given temperatures for each pair of materials or single material.
   - Uncertainties in unit cell constants/volume and temperature propagated to pressure using a PVT correlation matrix. Uncertainties in the joint PT estimation are also reported.
   - Many code changes and optimisations
- [NEW] Version 1.4beta (https://gitlab.desy.de/robert.farla/eoscross/-/tree/EosCross_v1.4beta)
   - Added new phases and their EoS.
     - Primary: Phase A, Olivine
     - Secondary: SiO2, Ti, Fe - and their phase diagrams
   - Code clean-up and fixes (e.g. pressure calculations for all EoS at once).  

## Installation
In order to use the tool, follow these easy steps.

1) Create a **clean** environment in Miniforge (e.g. named 'eoscross') and install the current Python version (v3.11). Experiment with newer versions at your own risk!

2) For the freshly created environment, open a terminal and install the dependencies by running:
`pip install -r requirements.txt`
You can now start the app in the script directory by running:
`python EosCross_Launcher.py`

3) **Important note on 30.11.2024** Burnman 2.* was released, which includes the calibrant files used by EosCross. Therefore, after installing the required packages in 'requirements.txt', the app should work right away.

4) **Optional** If you want to regenerate the provided requirements.txt file, install:
`pip install pipreqs`
...and run:
`pipreqs . --force`

## Troubleshooting

No problems are currently known.

## Usage
EosCross has a GUI and should be relatively straightfoward to use once you have the lattice parameters of your PT calibrants obtained by peak fitting the diffraction patterns in e.g. GSAS2 or PDIndexer (https://github.com/seto77/PDIndexer). 

## Screenshots
Main menu  
![SEosCross Launcher](https://gitlab.desy.de/robert.farla/eoscross/-/raw/EosCross_v1.3/EosCross_launcher.png) 

A pair of calibrants at room PT  
![SEosCross pair](https://gitlab.desy.de/robert.farla/eoscross/-/raw/EosCross_v1.3/EosCross_PTpair.png)

A pair of calibrants at high PT  
![SEosCross pair](https://gitlab.desy.de/robert.farla/eoscross/-/raw/EosCross_v1.3/EosCross_PTpair2.png)

## Support
Please visit the beamline station P61B website at https://photon-science.desy.de/facilities/petra_iii/beamlines/p61_high_energy_wiggler_beamline_lvp

## Technical information
The software uses the implementation of the Burnman code developed by Cottaar et al., 2016. EosCross now uses newly added Burnman calibrants that contain the EoS formalism and published parameters (V0, K0, K’0, γ0, etc.) required for the calculation of pressure (PVT calculation). The Burnman calibrant files were checked for reproducibiliy of tabulated data in each publication to ensure the calculations in EosCross are correct and reproducible. This software is open source and can be forked. There is no restriction on customising the user interface, or by expanding it with new pairs of PT calibrants. 
